@@ -25,7 +25,10 @@ __all__ = ['CoordinateHelper']
 
 
 def wrap_angle_at(values, coord_wrap):
-    return np.mod(values - coord_wrap, 360.) - (360. - coord_wrap)
+    # On ARM processors, np.mod emits warnings if there are NaN values in the
+    # array, although this doesn't seem to happen on other processors.
+    with np.errstate(invalid='ignore'):
+        return np.mod(values - coord_wrap, 360.) - (360. - coord_wrap)
 
 
 class CoordinateHelper(object):
@@ -292,6 +295,18 @@ class CoordinateHelper(object):
         """
         self.ticks.set_visible_axes(position)
 
+    def set_ticks_visible(self, visible):
+        """
+        Set whether ticks are visible or not.
+
+        Parameters
+        ----------
+        visible : bool
+            The visibility of ticks. Setting as ``False`` will hide ticks
+            along this coordinate.
+        """
+        self.ticks.set_visible(visible)
+
     def set_ticklabel(self, **kwargs):
         """
         Set the visual properties for the tick labels.
@@ -319,6 +334,18 @@ class CoordinateHelper(object):
         """
         self.ticklabels.set_visible_axes(position)
 
+    def set_ticklabel_visible(self, visible):
+        """
+        Set whether the tick labels are visible or not.
+
+        Parameters
+        ----------
+        visible : bool
+            The visibility of ticks. Setting as ``False`` will hide this
+            coordinate's tick labels.
+        """
+        self.ticklabels.set_visible(visible)
+
     def set_axislabel(self, text, minpad=1, **kwargs):
         """
         Set the text and optionally visual properties for the axis label.
@@ -711,6 +738,6 @@ class CoordinateHelper(object):
             field[1:, 1:][reset] = np.nan
 
         if len(tick_world_coordinates_values) > 0:
-            self._grid = self.parent_axes.contour(X, Y, field.transpose(), levels=tick_world_coordinates_values)
+            self._grid = self.parent_axes.contour(X, Y, field.transpose(), levels=np.sort(tick_world_coordinates_values))
         else:
             self._grid = None
