@@ -8,12 +8,14 @@ import matplotlib.pyplot as plt
 import astropy
 from astropy import units as u
 from astropy.wcs import WCS
-from astropy.tests.helper import pytest
+from astropy.tests.helper import pytest, remote_data
 
 from .. import WCSAxes
 from .test_images import BaseImageTests
 from ..transforms import CurvedTransform
 
+from . import baseline_dir
+
 requires_astropy_10 = pytest.mark.skipif(str(LooseVersion(astropy.__version__) < LooseVersion("1.0")))
 
 # Create fake transforms that roughly mimic a polar projection
@@ -58,7 +60,8 @@ class LonLatToDistance(CurvedTransform):
 
 class TestTransformCoordMeta(BaseImageTests):
 
-    @pytest.mark.mpl_image_compare(filename='coords_overlay.png', tolerance=1.5)
+    @remote_data
+    @pytest.mark.mpl_image_compare(baseline_dir=baseline_dir, filename='coords_overlay.png', tolerance=1.5)
     def test_coords_overlay(self):
 
         # Set up a simple WCS that maps pixels to non-projected distances
@@ -106,7 +109,8 @@ class TestTransformCoordMeta(BaseImageTests):
         return fig
 
     @requires_astropy_10
-    @pytest.mark.mpl_image_compare(filename='coords_overlay_auto_coord_meta.png', tolerance=1.5)
+    @remote_data
+    @pytest.mark.mpl_image_compare(baseline_dir=baseline_dir, filename='coords_overlay_auto_coord_meta.png', tolerance=1.5)
     def test_coords_overlay_auto_coord_meta(self):
 
         fig = plt.figure(figsize=(4, 4))
@@ -128,7 +132,8 @@ class TestTransformCoordMeta(BaseImageTests):
 
         return fig
 
-    @pytest.mark.mpl_image_compare(filename='direct_init.png', tolerance=1.5)
+    @remote_data
+    @pytest.mark.mpl_image_compare(baseline_dir=baseline_dir, filename='direct_init.png', tolerance=1.5)
     def test_direct_init(self):
 
         s = DistanceToLonLat(R=6378.273)
